@@ -6,7 +6,7 @@ use warnings;
 use Mo qw(build is);
 use Mo::utils qw(check_bool check_length check_number check_required);
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 has active => (
 	is => 'ro',
@@ -117,6 +117,17 @@ Get hash type name.
 
 Returns string.
 
+=head1 ERRORS
+
+ new():
+         Parameter 'active' must be a bool (0/1).
+                 Value: %s
+         Parameter 'id' must be a number.
+                 Value: %s
+         Parameter 'name' has length greater than '50'.
+                 Value: %s
+         Parameter 'name' is required.
+
 =head1 EXAMPLE
 
 =for comment filename=create_and_print_hash_type.pl
@@ -129,7 +140,7 @@ Returns string.
  my $obj = Data::HashType->new(
          'active' => 1,
          'id' => 10,
-         'name' => 'SHA256',
+         'name' => 'SHA-256',
  );
 
  # Print out.
@@ -138,7 +149,7 @@ Returns string.
  print 'Id: '.$obj->id."\n";
 
  # Output:
- # Name: SHA256
+ # Name: SHA-256
  # Active: 1
  # Id: 10
 
@@ -165,6 +176,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
